#!/usr/bin/env bash

ABSDIR="$( dirname "$(readlink -f -- "$0")" )"
source ${ABSDIR}/../functions.sh
source ${ABSDIR}/vars.sh

ensure_pwd_is_scriptdir
ensure_not_root

ensure_variables_are_defined "$envvars"

if podman volume exists ${confvolume} || podman volume exists ${dbvolume}; then
	echo "Files or volumes from previous installation already exists"
	echo "Please remove them before fresh install, or try continue with normal installation"
	exit 1
fi

podman image pull ${synapse_image}:${synapse_version} &&
podman image exists ${synapse_image}:${synapse_version} &&
podman volume create ${confvolume} &&
podman volume create ${dbvolume} &&
podman container run -it --name ${container_name}-generate --mount type=volume,src=${confvolume},dst=/data -e SYNAPSE_SERVER_NAME=${GARBAYE_MATRIX_DOMAIN} -e SYNAPSE_REPORT_STATS=no ${synapse_image}:${synapse_version} generate &&
podman container rm ${container_name}-generate &&
podman unshare sed -i -e "s|^#public_baseurl: https://example.com/$|public_baseurl: ${GARBAYE_MATRIX_URL}|g" `get_podman_volume_path ${confvolume}`/homeserver.yaml &&
podman unshare sed -z -i -e "s|database:\n  name: sqlite3\n  args:\n    database: /data/homeserver.db|database:\n  name: psycopg2\n  args:\n    user: synapse\n    password: ${GARBAYE_MATRIX_POSTGRES_PASSWORD}\n    database: synapse\n    host: synapse-db\n    port: 5432\n    cp_min: 5\n    cp_max: 10|g" `get_podman_volume_path ${confvolume}`/homeserver.yaml &&
podman unshare sed -i -e "s|^#enable_registration: false$|enable_registration: false|g" `get_podman_volume_path ${confvolume}`/homeserver.yaml &&
podman unshare sed -i -e "s|^#allow_public_rooms_over_federation: true$|allow_public_rooms_over_federation: true|g" `get_podman_volume_path ${confvolume}`/homeserver.yaml &&
${ABSDIR}/10_install.sh

