#!/usr/bin/env bash

ABSDIR="$( dirname "$(readlink -f -- "$0")" )"
source ${ABSDIR}/../functions.sh
source ${ABSDIR}/vars.sh

ensure_pwd_is_scriptdir
ensure_not_root

buildfolder=/tmp/synapse-$$

if ! podman image exists ${synapse_image}:${synapse_version}; then
    mkdir ${buildfolder} &&
    curl -sSfL -- "https://github.com/matrix-org/synapse/archive/refs/tags/${synapse_version}.tar.gz" | \tar xz --strip-components 1 -C ${buildfolder}/ && {
        podman image pull docker.io/moby/buildkit:latest
        podman container run -d --name buildkitd --privileged docker.io/moby/buildkit:latest &&
        my_buildctl --addr=podman-container://buildkitd build \
		       --frontend dockerfile.v0 \
		       --local context=${buildfolder}/ \
		       --local dockerfile=${buildfolder}/docker/ \
		       --output type=oci,name="${synapse_image}:${synapse_version}" | \
                       podman image load &&
	podman container rm --force buildkitd &&
	podman image rm docker.io/moby/buildkit:latest
    }
    rm -rf ${buildfolder}
else
    echo "Image ${synapse_image}:${synapse_version} already built"
fi &&

oci_push_to_registry ${synapse_image}:${synapse_version}
